@@ -202,6 +202,18 @@ class Assistant(AssistantBase):
         default_factory=list,
         description="List of categories for marketplace classification (e.g., 'quality-assurance', 'data-analysis')",
     )
+    unique_users_count: int = Field(
+        default=0,
+        description="Number of unique users who have interacted with this assistant",
+    )
+    unique_likes_count: Optional[int] = Field(
+        default=None,
+        description="Number of unique likes for this assistant",
+    )
+    unique_dislikes_count: Optional[int] = Field(
+        default=None,
+        description="Number of unique dislikes for this assistant",
+    )
 
 
 class AssistantRequestBase(AssistantBase):
@@ -494,3 +506,18 @@ class AssistantEvaluationRequest(BaseModel):
     llm_model: Optional[str] = Field(
         default=None, description="LLM model to use for evaluation"
     )
+
+
+class ReactionType(str, Enum):
+    """Enum for reaction types."""
+
+    LIKE = "like"
+    DISLIKE = "dislike"
+
+
+class ReactionRequest(BaseModel):
+    """Model for assistant reaction request."""
+
+    model_config = ConfigDict(extra="ignore", use_enum_values=True)
+
+    reaction: ReactionType = Field(description="Reaction type: 'like' or 'dislike'")
