@@ -23,6 +23,7 @@ from ..models.assistant import (
     Context,
     ExportAssistantPayload,
     AssistantEvaluationRequest,
+    ReactionRequest,
 )
 from ..models.common import PaginationParams
 from ..utils import ApiRequestHandler
@@ -520,3 +521,32 @@ class AssistantService:
         return self._api.post(
             f"/v1/assistants/{assistant_id}/marketplace/publish/validate", dict
         )
+
+    def react(self, assistant_id: str, request: ReactionRequest) -> dict:
+        """React to an assistant with like or dislike.
+
+        If the user already has the opposite reaction, it will be removed.
+
+        Args:
+            assistant_id: ID of the assistant to react to
+            request: Reaction request containing reaction type ('like' or 'dislike')
+
+        Returns:
+            Response from the API
+        """
+        return self._api.post(
+            f"/v1/assistants/{assistant_id}/reactions",
+            dict,
+            json_data=request.model_dump(exclude_none=True),
+        )
+
+    def remove_reactions(self, assistant_id: str) -> dict:
+        """Remove all reactions (likes/dislikes) from an assistant for the current user.
+
+        Args:
+            assistant_id: ID of the assistant to remove reactions from
+
+        Returns:
+            Response from the API
+        """
+        return self._api.delete(f"/v1/assistants/{assistant_id}/reactions", dict)
